@@ -10,14 +10,18 @@ use Getopt::Long;
 use Module::Pluggable search_path => ['App::Metabase::Relayd::Plugin'];
 use Module::Load::Conditional qw[can_load];
 BEGIN {
-  sub POE::Kernel::USE_SIGCHLD () { 1 }
+  no strict 'refs';
+  no warnings;
+  *{ 'POE::Kernel::USE_SIGCHLD' } = sub () { 1 };
+}
+BEGIN {
   use POE;
 }
 use POE::Component::Metabase::Relay::Server;
 
 use vars qw($VERSION);
 
-$VERSION = '0.20';
+$VERSION = '0.22';
 
 sub _metabase_dir {
   return $ENV{PERL5_MBRELAYD_DIR} 
